import * as api from '../api'
export default {
  data() {
    const UA = window.navigator.userAgent
    const isMobile = /android|iphone|ipad|ipod/i.test(UA)
    return {
      isMobile,
      isWechat: isMobile && /micromessenger/i.test(UA),
      openId: window.localStorage.getItem('open_id')
    }
  },
  watch: {
    code: {
      immediate: true,
      handler(code) {
        if (code && !this.openId) {
          this.handlePay()
        }
      }
    },
    orderNo: {
      immediate: true,
      handler(orderNo) {
        orderNo && this.getOrder()
      }
    }
  },
  computed: {
    code() {
      return this.$route.query.code
    },
    orderNo() {
      const orderNo = this.$route.query.order_no
      return Array.isArray(orderNo) ? orderNo.pop() : orderNo
    }
  },
  methods: {
    // 创建微信订单
    createWxPayOrder(product, num = 1) {
      const params = {
        open_id: this.openId,
        buy_count: num + '',
        payment_method: '3',
        shop_id: product.shop_id,
        spu_id: product.spu_id,
        sku_id: product.sku_id,
        notify_url: `${process.env.VUE_APP_BASE_API}/api/lms/v2/lobby/update-status-api/${this.pid}`
      }
      return api.createOrder(params).then(order => {
        const redirectURI = `${location.href}&order_no=${order.order_id}`
        // 去支付
        window.location.href = `https://web-pay.ezijing.com/wxpay/h5?prepay_id=${order.pay_order_id}&open_id=${this.openId}&redirect_uri=${encodeURIComponent(
          redirectURI
        )}`
      })
    },
    // 获取微信code
    getCode() {
      const redirectURI = `https://pages.ezijing.com/given/auth.html?redirect_uri=${encodeURIComponent(location.href)}`
      window.location.href = `https://open.weixin.qq.com/connect/oauth2/authorize?appid=wx451c01d40d090d7a&redirect_uri=${redirectURI}&response_type=code&scope=snsapi_base#wechat_redirect`
    },
    // 获取微信openid
    getOpenId(callback) {
      if (!this.code) {
        this.getCode()
        return
      }
      api.getOpenId({ code: this.code, identity: 'ezijing' }).then(response => {
        if (response.code === 0) {
          this.openId = response.openid
          window.localStorage.setItem('open_id', this.openId)
          callback && callback(response)
        } else {
          this.getCode()
        }
      })
    },
    getOrder() {
      const params = {
        shop_id: this.product.shop_id,
        spu_id: this.product.spu_id,
        order_id: this.orderNo
      }
      return api.getOrderList(params).then(response => {
        const [order = {}] = response.data
        if (order.order_status === '4') {
          // 支付成功
          this.handlePaySuccess()
        }
        return order
      })
    },
    // 微信JSAPI支付
    handleWxJSAPIPay(product, num) {
      this.openId
        ? this.createWxPayOrder(product, num)
        : this.getOpenId(() => {
            this.createWxPayOrder(product, num)
          })
    }
  }
}
